ToolConfig class
Properties
- dir → Directory
-
final
- file → File
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
lastResults
↔ Map<
String, dynamic> ? -
getter/setter pair
-
profiles
↔ Map<
String, ToolProfile> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
) → Future< void> -
setLastResults(
Map< String, dynamic> r) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
load(
) → Future< ToolConfig>